require 'spec_helper'

describe Rustle::Strip do
  context "when initializing" do
    it "should require a receiver" do
      expect { Rustle::Strip.new(nil, 30) }.to raise_error(Rustle::ReceiverNotFound)
    end

    it "should require an LED count" do
      receiver = Rustle::Receiver.new(nil, debug: true)
      expect { Rustle::Strip.new(receiver, nil) }.to raise_error(Rustle::NumLEDsInvalid)
    end
  end

  describe "queue" do
    let(:strip) { Rustle::Receiver.new(nil, num_leds: 5, debug: true).strip }

    it "should be initialized with a black frame" do
      expect(strip.current_frame).to_not be_nil
    end

    it "should be initialized with a black frame" do
      frame = Rustle::Frame.new [Rustle::Color.new(255, 0, 0)] * 5

      strip.queue_frames [frame]
      expect(strip.next_frame).to_not be_nil

      # After advancing to the next frame, there shouldn't be a next_frame
      strip.next_frame!
      expect(strip.next_frame).to eq(strip.current_frame)
    end
  end
end
